# proof-business-api

API client for Proof's business API which is for document notarizing and secure signing.

Proof is a document signing and notarizing client which allows one to send a document package with notarization requirements and limitations.

Documents can be uploaded together as byte64 encoded strings or uploaded to draft transactions individually. Documents will then be sent to provided emails and SMS numbers for secure signing which can include activation dates and end dates.

